/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.e2e.engine.scenario.function;

import org.apache.shenyu.e2e.client.gateway.GatewayClient;
import org.java_websocket.client.WebSocketClient;
import org.slf4j.MDC;

import java.util.function.Supplier;

/**
 * WebSocket Checker interface.
 */
@FunctionalInterface
public interface WebSocketChecker extends Checker, WebSocketVerifier {

    /**
     * check websocket client.
     * @param client client
     */
    default void check(GatewayClient client) {
        check(client.getWebSocketClientSupplier(), client);
    }

    /**
     * check request specification.
     * @param supplier supplier
     * @param client client
     */
    default void check(Supplier<WebSocketClient> supplier, GatewayClient client) {
        try {
            verify(supplier.get(), client);
        } catch (AssertionError e) {
            throw new AssertionError("failed to request " + MDC.get("endpoint"), e);
        }
    }
}
