/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.alibaba.dubbo.handler;

import org.apache.shenyu.common.dto.MetaData;
import org.apache.shenyu.plugin.alibaba.dubbo.cache.AlibabaDubboConfigCache;
import org.apache.shenyu.plugin.dubbo.common.handler.AbstractDubboMetaDataHandler;

import java.util.Objects;

/**
 * The type Alibaba dubbo meta data handler.
 */
public class AlibabaDubboMetaDataHandler extends AbstractDubboMetaDataHandler {

    @Override
    protected boolean isInitialized(final MetaData metaData) {
        return Objects.nonNull(AlibabaDubboConfigCache.getInstance().get(metaData.getPath()));
    }

    @Override
    protected void initReference(final MetaData metaData) {
        AlibabaDubboConfigCache.getInstance().initRef(metaData);
    }

    @Override
    protected void updateReference(final MetaData metaData) {
        AlibabaDubboConfigCache.getInstance().build(metaData);
    }

    @Override
    protected void invalidateReference(final String path) {
        AlibabaDubboConfigCache.getInstance().invalidate(path);
    }
}
